.. include:: /includes/_links.rst

Downloads
=========

.. toctree::
   :maxdepth: 2

The PySNMP software is provided under terms and conditions of BSD-style
license, and can be freely downloaded from `PySNMP PyPI package`_.

Besides official releases, if you want to try the cutting-edge development
code then it could be taken from `PySNMP GitHub repository`_. It may
be less stable in regards to general operation and changes to public
interfaces, but it's first to contain fixes to recently discovered bugs.

The best way to obtain PySNMP and dependencies is to run:

.. code-block:: bash

   $ pip install pysnmp

Related Resources
-----------------

- `Support Options`_
- :doc:`/quick-start`
- :doc:`/troubleshooting`
- :doc:`/faq`
